@@ -11,6 +11,9 @@ from sqlalchemy.orm import Session
 
 from nowcasting_forecast import N_GSP, __version__
 from nowcasting_forecast.batch import make_batches
+from nowcasting_forecast.models.nwp_simple_trained.nwp_simple_trained import (
+    nwp_irradiance_simple_trained_run_all_batches,
+)
 from nowcasting_forecast.models.nwp_solar_simple import nwp_irradiance_simple_run_all_batches
 from nowcasting_forecast.utils import floor_30_minutes_dt
 
@@ -32,7 +35,14 @@ logger = logging.getLogger(__name__)
     help="Option to make Fake forecasts",
     type=click.BOOL,
 )
-def run(db_url: str, fake: bool = False):
+@click.option(
+    "--model-name",
+    default="nwp_simple",
+    envvar="MODEL_NAME",
+    help="Select which model to use",
+    type=click.STRING,
+)
+def run(db_url: str, fake: bool = False, model_name: str = "nwp_simple"):
     """
     Run main app.
 
@@ -48,14 +58,26 @@ def run(db_url: str, fake: bool = False):
             forecasts = make_dummy_forecasts(session=session)
         else:
 
+            if model_name == "nwp_simple":
+                config_filename = "nowcasting_forecast/config/mvp_v0.yaml"
+            else:
+                config_filename = "nowcasting_forecast/config/mvp_v1.yaml"
+
             with tempfile.TemporaryDirectory() as temporary_dir:
                 # make batches
-                make_batches(temporary_dir=temporary_dir)
+                make_batches(temporary_dir=temporary_dir, config_filename=config_filename)
 
                 # make forecasts
-                forecasts = nwp_irradiance_simple_run_all_batches(
-                    session=session, batches_dir=temporary_dir
-                )
+                if model_name == "nwp_simple":
+                    forecasts = nwp_irradiance_simple_run_all_batches(
+                        session=session, batches_dir=temporary_dir
+                    )
+                elif model_name == "nwp_simple_trained":
+                    forecasts = nwp_irradiance_simple_trained_run_all_batches(
+                        session=session, batches_dir=temporary_dir
+                    )
+                else:
+                    raise NotImplementedError(f"model name {model_name} has not be implemented. ")
 
         # save forecasts
         save(forecasts=forecasts, session=session)
